@@ -283,6 +283,8 @@ static xcb_window_t getParentWindow(xcb_window_t WId)
 class KWinInterface
 {
     typedef int (*ClientMaximizeMode)(const void *);
+    typedef int (*ShellClientMaximizeMode)(const void *);
+    typedef void (*WorkspaceSetDarkTheme)(void *, bool);
     typedef void (*ClientMaximize)(void *, KWinUtils::MaximizeMode);
     typedef void (*ActivateClient)(void*, void*, bool force);
     typedef void (*ClientUpdateCursor)(void *);
@@ -304,6 +306,8 @@ public:
     KWinInterface()
     {
         clientMaximizeMode = (ClientMaximizeMode)KWinUtils::resolve("_ZNK4KWin6Client12maximizeModeEv");
+        shellClientMaximizeMode = (ShellClientMaximizeMode)KWinUtils::resolve("_ZNK4KWin11ShellClient12maximizeModeEv");
+        setDarkTheme = (WorkspaceSetDarkTheme)KWinUtils::resolve("_ZN4KWin9Workspace12setDarkThemeEb");
         clientMaximize = (ClientMaximize)KWinUtils::resolve("_ZN4KWin14AbstractClient8maximizeENS_12MaximizeModeE");
         activateClient = (ActivateClient)KWinUtils::resolve("_ZN4KWin9Workspace14activateClientEPNS_14AbstractClientEb");
         clientUpdateCursor = (ClientUpdateCursor)KWinUtils::resolve("_ZN4KWin14AbstractClient12updateCursorEv");
@@ -332,6 +336,8 @@ public:
 
     ClientWindowType clientWindowType;
     ClientMaximizeMode clientMaximizeMode;
+    ShellClientMaximizeMode shellClientMaximizeMode;
+    WorkspaceSetDarkTheme setDarkTheme;
     ClientMaximize clientMaximize;
     ActivateClient activateClient;
     ClientUpdateCursor clientUpdateCursor;
@@ -680,21 +686,23 @@ QObject *KWinUtils::findClient(KWinUtils::Predicate predicate, quint32 window)
 {
     if (!workspace())
         return nullptr;
-    if (QX11Info::isPlatformX11()) {
-        if (predicate == Predicate::UnmanagedMatch) {
-            if (!interface->findUnmanaged)
-                return nullptr;
-
-            return interface->findUnmanaged(workspace(), window);
+    if (!QX11Info::isPlatformX11()) {
+        QObject *shellClient = interface->findShellClient(workspace(), window);
+        if (shellClient) {
+            return shellClient;
         }
-
-        if (!interface->findClient)
+    }
+    if (predicate == Predicate::UnmanagedMatch) {
+        if (!interface->findUnmanaged)
             return nullptr;
 
-        return interface->findClient(workspace(), predicate, window);
-    } else {
-        return interface->findShellClient(workspace(), window);
+        return interface->findUnmanaged(workspace(), window);
     }
+
+    if (!interface->findClient)
+        return nullptr;
+
+    return interface->findClient(workspace(), predicate, window);
 }
 
 void KWinUtils::clientUpdateCursor(QObject *client)
@@ -988,6 +996,9 @@ QVariant KWinUtils::getParentWindow(const QObject *window) const
 
 QVariant KWinUtils::isFullMaximized(const QObject *window) const
 {
+    if (!isPlatformX11() && !interface->shellClientMaximizeMode) {
+        return QVariant();
+    }
     if (!interface->clientMaximizeMode) {
         return QVariant();
     }
@@ -1003,6 +1014,11 @@ void KWinUtils::activateClient(QObject *window)
     }
 }
 
+void KWinUtils::setDarkTheme(bool isDark)
+{
+    interface->setDarkTheme(workspace(), isDark);
+}
+
 QVariant KWinUtils::fullmaximizeWindow(QObject *window) const
 {
     if (!interface->clientMaximize) {
@@ -1181,10 +1197,10 @@ void KWinUtils::QuickTileWindow(uint side)
 
 void KWinUtils::ShowWorkspacesView()
 {
-    QObject *multitasking = KWin::getEffect("com.deepin.multitasking");
+    QObject *multitasking = KWin::getEffect("multitaskview");
 
     if (multitasking) {
-        QMetaObject::invokeMethod(multitasking, "toggleActive");
+        QMetaObject::invokeMethod(multitasking, "toggle");
     }
 }
 
@@ -1254,6 +1270,16 @@ bool KWinUtils::Window::isFullMaximized(const QObject *window)
         return false;
     }
 
+    if (!isPlatformX11()) {
+        if (!interface->shellClientMaximizeMode) {
+            return false;
+        }
+        else {
+            if (interface->shellClientMaximizeMode(window) == MaximizeFull) {
+                return true;
+            }
+        }
+    }
     if (!interface->clientMaximizeMode) {
         return false;
     }
